# Changelog

All notable changes to this project will be documented in this file.

## [unreleased]

### 🚜 Refactor

- *(project)* Moved this project from kitchenai mono-repo as a standalone

<!-- generated by git-cliff -->
